SWDEV-482059 SWDEV-476745 - Add image support check
Add image support check before hipMallocArray().
Change-Id: I9efed88d791ee1b2b4465286b3341b821f7bf628
[ROCm/hip-tests commit: b4694a6bab]
This commit is contained in:
gecommit door
Maneesh Gupta
bovenliggende
cbd270ab58
commit
4b0437de28
@@ -50,6 +50,7 @@ TEST_CASE("Unit_hipMemcpyAtoA_Basic") {
|
|||||||
return;
|
return;
|
||||||
#else
|
#else
|
||||||
HIP_CHECK(hipSetDevice(0));
|
HIP_CHECK(hipSetDevice(0));
|
||||||
|
CHECK_IMAGE_SUPPORT
|
||||||
int row, col;
|
int row, col;
|
||||||
row = 1;
|
row = 1;
|
||||||
col = GENERATE(3, 4, 100);
|
col = GENERATE(3, 4, 100);
|
||||||
|
|||||||
@@ -48,6 +48,7 @@ TEST_CASE("Unit_hipMemcpyAtoD_Basic") {
|
|||||||
return;
|
return;
|
||||||
#else
|
#else
|
||||||
HIP_CHECK(hipSetDevice(0));
|
HIP_CHECK(hipSetDevice(0));
|
||||||
|
CHECK_IMAGE_SUPPORT
|
||||||
int row, col;
|
int row, col;
|
||||||
row = 1;
|
row = 1;
|
||||||
col = GENERATE(3, 4, 100);
|
col = GENERATE(3, 4, 100);
|
||||||
|
|||||||
@@ -48,6 +48,7 @@ TEST_CASE("Unit_hipMemcpyAtoHAsync_Basic") {
|
|||||||
return;
|
return;
|
||||||
#else
|
#else
|
||||||
HIP_CHECK(hipSetDevice(0));
|
HIP_CHECK(hipSetDevice(0));
|
||||||
|
CHECK_IMAGE_SUPPORT
|
||||||
int row, col;
|
int row, col;
|
||||||
row = 1;
|
row = 1;
|
||||||
col = GENERATE(3, 4, 100);
|
col = GENERATE(3, 4, 100);
|
||||||
|
|||||||
Verwijs in nieuw issue
Block a user